set INTERFACE_REPO "../../AEAD"
set TOP_LEVEL_NAME AEAD_TB
set STOP_AT_FAULT True
set CUSTOM_DO_FILE "wave.do"
set PWIDTH 32
set SWIDTH 32

# ----------------------------------------
# AES_Enc_KOF add
# Set implementation files
set src_vhdl [subst {
    "$INTERFACE_REPO/src_rtl_hs/AEAD_pkg.vhd"

	"../src_rtl/AES_ENC_GMU/AES_pkg.vhd"

    "../src_rtl/CipherCore.vhd"

    "$INTERFACE_REPO/src_rtl_hs/PreProcessor.vhd"
    "$INTERFACE_REPO/src_rtl_hs/PostProcessor.vhd"
    "$INTERFACE_REPO/src_rtl_hs/fwft_fifo.vhd"
    "../src_rtl/AEAD.vhd"
    "$INTERFACE_REPO/src_rtl_hs/AEAD_Arch.vhd"
    "$INTERFACE_REPO/src_rtl_hs/wrappers/CipherCore_Wrapper.vhd"
    "$INTERFACE_REPO/src_rtl_hs/wrappers/AEAD_Wrapper.vhd"

	"../src_rtl/AES_ENC_GMU/AES_Sbox.vhd"
	"../src_rtl/AES_ENC_GMU/AES_map.vhd"
	"../src_rtl/AES_ENC_GMU/AES_invmap.vhd"
	"../src_rtl/AES_ENC_GMU/AES_SubBytes.vhd"
	"../src_rtl/AES_ENC_GMU/AES_ShiftRows.vhd"
	"../src_rtl/AES_ENC_GMU/AES_mul.vhd"
	"../src_rtl/AES_ENC_GMU/AES_MixColumn.vhd"
	"../src_rtl/AES_ENC_GMU/AES_MixColumns.vhd"
	"../src_rtl/AES_ENC_GMU/AES_Round.vhd"
	"../src_rtl/AES_ENC_GMU/AES_KeyUpdate.vhd"
	"../src_rtl/AES_ENC_GMU/AES_Enc_KOF_Datapath.vhd"
	"../src_rtl/AES_ENC_GMU/AES_Enc_KOF_Control.vhd"
	"../src_rtl/AES_ENC_GMU/AES_Enc_KOF.vhd"

}]

# ----------------------------------------



# ----------------------------------------
# Set simulation files
set tb_vhdl [subst {
    "$INTERFACE_REPO/src_tb/std_logic_1164_additions.vhd"
    "$INTERFACE_REPO/src_tb/$TOP_LEVEL_NAME.vhd"
}]
# ----------------------------------------
# Python interface for creating a distro
proc get_src {src}  {return $src}

# ----------------------------------------
# Create compilation libs
proc ensure_lib { lib } { if ![file isdirectory $lib] { vlib $lib } }
ensure_lib          ./libs/
ensure_lib          ./libs/work/
vmap       work     ./libs/work/

# ----------------------------------------
# Compile implementation files
alias imp_com {
    echo "imp_com"
    foreach f $src_vhdl {vcom -quiet -work work $f}
}

# ----------------------------------------
# Compile simulation files
alias sim_com {
    echo "sim_com"
    foreach f $tb_vhdl {vcom -quiet -work work $f}
}

# ----------------------------------------
# Compile simulation files
alias com {
    echo "com"
    imp_com
    sim_com
}

# ----------------------------------------
# Add wave form and run
alias run_wave {
    echo "\[exec\] run_wave"
    add wave -group PreProcessor  -ports     -radix hexadecimal $TOP_LEVEL_NAME/uut/u_input/*
    add wave -group PreProcessor  -internals -radix hexadecimal $TOP_LEVEL_NAME/uut/u_input/*
    add wave -group CipherCore    -ports     -radix hexadecimal $TOP_LEVEL_NAME/uut/u_cc/*
    add wave -group CipherCore    -internals -radix hexadecimal $TOP_LEVEL_NAME/uut/u_cc/*
    add wave -group PostProcessor -ports     -radix hexadecimal $TOP_LEVEL_NAME/uut/u_output/*
    add wave -group PostProcessor -internals -radix hexadecimal $TOP_LEVEL_NAME/uut/u_output/*

    # Configure wave panel
    configure wave -namecolwidth 180
    configure wave -valuecolwidth 200
    configure wave -signalnamewidth 1
    configure wave -timelineunits ns
    WaveRestoreZoom {0 ps} {2000 ns}
    configure wave -justifyvalue right
    configure wave -rowmargin 8
    configure wave -childrowmargin 5

#add from
	add wave -noupdate /aead_tb/uut/u_cc/clk
	add wave -noupdate /aead_tb/uut/u_cc/decrypt
	add wave -noupdate /aead_tb/uut/u_cc/key_update
	add wave -noupdate /aead_tb/uut/u_cc/key_valid
	add wave -noupdate /aead_tb/uut/u_cc/key_ready
	add wave -noupdate -divider {New Divider}
	add wave -noupdate /aead_tb/uut/u_cc/bdi_valid
	add wave -noupdate -radix hexadecimal /aead_tb/uut/u_cc/bdi
	add wave -noupdate /aead_tb/uut/u_cc/bdi_ready
	add wave -noupdate -radix unsigned /aead_tb/uut/u_cc/bdi_type
	add wave -noupdate -divider {New Divider}
	add wave -noupdate /aead_tb/uut/u_cc/bdo_ready
	add wave -noupdate -radix hexadecimal /aead_tb/uut/u_cc/bdo
	add wave -noupdate /aead_tb/uut/u_cc/bdo_valid
	add wave -noupdate -divider {New Divider}
	add wave -noupdate -radix hexadecimal /aead_tb/uut/u_cc/aes_in_node
	add wave -noupdate -radix hexadecimal /aead_tb/uut/u_cc/aes_out_node
	add wave -noupdate -divider {New Divider}
	add wave -noupdate /aead_tb/uut/u_cc/aes_start_reg
	add wave -noupdate /aead_tb/uut/u_cc/aes_finish
	add wave -noupdate /aead_tb/uut/u_cc/state_reg
	add wave -noupdate /aead_tb/uut/u_cc/u0/ready

#add to



}


# ----------------------------------------
# Compile all the design files and elaborate the top level design with -novopt
alias ldd {
    com
    set run_do_file [file isfile $CUSTOM_DO_FILE]
    if {$run_do_file == 1} {
        vsim -novopt -t ps -L work $TOP_LEVEL_NAME -gG_PWIDTH=$PWIDTH -gG_SWIDTH=$SWIDTH  -do $CUSTOM_DO_FILE  -gG_STOP_AT_FAULT=$STOP_AT_FAULT
    } else {
      vsim -novopt -t ps -L work $TOP_LEVEL_NAME -gG_PWIDTH=$PWIDTH -gG_SWIDTH=$SWIDTH  -gG_STOP_AT_FAULT=$STOP_AT_FAULT
      run_wave
    }
    run 30 us
}

# ----------------------------------------
# Print out user commmand line aliases
alias h {
    echo "List Of Command Line Aliases"
    echo
    echo "imp_com                       -- Compile implementation files"
    echo
    echo "sim_com                       -- Compile simulation files"
    echo
    echo "com                           -- Compile files in the correct order"
    echo
    echo "ldd                           -- Compile and run"
    echo
}
h
